@@ -95,6 +95,8 @@ def _process_svs_pfile(pfile):
         data, meta, dwelltime, fname_suffix = _process_oslaser(pfile)
     elif psd == 'gaba':
         data, meta, dwelltime, fname_suffix = _process_gaba(pfile)
+    elif 'jpress_ac' in psd:  # Bergen patch
+        data, meta, dwelltime, fname_suffix = _process_gaba(pfile)
     else:
         raise UnsupportedPulseSequenceError(f'Unrecognised sequence {psd}.')
 
@@ -162,7 +164,7 @@ def _process_oslaser(pfile):
 
     dwelltime = 1 / pfile.hdr.rhr_spectral_width
 
-    return data, dwelltime, fname_suffix
+    return data, meta, dwelltime, fname_suffix
 
 
 def _process_gaba(pfile):
@@ -202,7 +204,8 @@ def _process_mrsi_pfile(pfile):
     '''
     psd = pfile.hdr.rhi_psdname.decode('utf-8').lower()
 
-    if psd != 'probe-p':
+    if psd != 'probe-p' \
+            and psd != 'probe-sl':
         raise UnsupportedPulseSequenceError('Unrecognised sequence, psdname must be "probe-p".')
 
     warn('The interpretation of pfile CSI data is poorly tested; rotations or transpositions of the'
