@@ -306,7 +306,7 @@ def process_siemens_csi_vx(img, verbose):
                       img.csa_header['tags']['PixelSpacing']['items'][1],
                       img.csa_header['tags']['SliceThickness']['items'][0]])
 
-    # Note that half_shift = True. For an explination see spec2nii/notes/siemens.md
+    # Note that half_shift = True. For an explanation see spec2nii/notes/siemens.md
     currNiftiOrientation = dcm_to_nifti_orientation(imageOrientationPatient,
                                                     imagePositionPatient,
                                                     xyzMM,
@@ -578,16 +578,13 @@ def identify_integrated_references(img, inst_num):
         if inst_num <= num_ref:
             # First ecc calibration references
             return 1, '_ecc'
-        elif inst_num > num_ref\
-                and inst_num <= (num_ref * 2):
+        elif inst_num <= (num_ref * 2):
             # First quantitation calibration references
             return 2, '_quant'
-        elif inst_num <= (total_dyn - num_ref)\
-                and inst_num > (total_dyn - (2 * num_ref)):
+        elif (total_dyn - (2 * num_ref)) < inst_num <= (total_dyn - num_ref):
             # Second ecc calibration references
             return 1, '_ecc'
-        elif inst_num <= total_dyn\
-                and inst_num > (total_dyn - num_ref):
+        elif (total_dyn - num_ref) < inst_num <= total_dyn:
             # Second quantitation calibration references
             return 2, '_quant'
         else:
