@@ -69,11 +69,7 @@ def is_xa_product(hdr):
         if any([seq_name == seq for seq in xa_product_seq]):
             return True
 
-    if xa_or_vx(hdr) == 'xa'\
-            and is_product():
-        return True
-    else:
-        return False
+    return xa_or_vx(hdr) == 'xa' and is_product()
 
 
 def process_twix(twixObj, base_name_out, name_in, dataKey, dim_overides, quiet=False, verbose=False, remove_os=False):
@@ -136,7 +132,7 @@ def process_svs(twixObj, base_name_out, name_in, dataKey, dim_overides, remove_o
 
     # Perform Orientation calculations
     # 1) Calculate dicom like imageOrientationPatient,imagePositionPatient,pixelSpacing and slicethickness
-    orient = twix2DCMOrientation(twixObj['hdr'], verbose=verbose)
+    orient = twix2DCMOrientation(twixObj['hdr'], force_svs=True, verbose=verbose)
     imageOrientationPatient, imagePositionPatient, pixelSpacing, slicethickness = orient
 
     # 2) In the style of dcm2niix calculate the affine matrix
@@ -312,7 +308,7 @@ def assemble_nifti_mrs(data, dwellTime, orientation, meta_obj, dim_tags):
     return nifti_mrs.NIfTI_MRS(data, orientation.Q44, dwellTime, meta_obj)
 
 
-def twix2DCMOrientation(mapVBVDHdr, verbose=False):
+def twix2DCMOrientation(mapVBVDHdr, force_svs=False, verbose=False):
     """ Convert twix orientation information to DICOM equivalent.
 
     Convert orientation to DICOM imageOrientationPatient, imagePositionPatient,
@@ -320,6 +316,7 @@ def twix2DCMOrientation(mapVBVDHdr, verbose=False):
 
     Args:
         mapVBVDHdr (dict): Header info interpreted by pymapVBVD
+        force_svs (bool,optionl): Forces svs orientation information (size) to be read
         verbose (bool,optionl)
     Returns:
         imageOrientationPatient
@@ -336,9 +333,12 @@ def twix2DCMOrientation(mapVBVDHdr, verbose=False):
             raise ValueError('In slice-selective spectroscopy, only the first slice is supported')
 
     # Orientation information
+    # Added the force_svs because in some sequences there are slice objects initilised
+    # and recorded but this seems sporadic behaviour.
     if ('sSpecPara', 'sVoI', 'sNormal', 'dSag') in mapVBVDHdr['MeasYaps']:
         NormaldSag = mapVBVDHdr['MeasYaps'][('sSpecPara', 'sVoI', 'sNormal', 'dSag')]
-    elif ('sSliceArray', 'asSlice', '0', 'sNormal', 'dSag') in mapVBVDHdr['MeasYaps']:
+    elif ('sSliceArray', 'asSlice', '0', 'sNormal', 'dSag') in mapVBVDHdr['MeasYaps']\
+            and not force_svs:
         # This is for slice-selective spectroscopy
         NormaldSag = mapVBVDHdr['MeasYaps'][('sSliceArray', 'asSlice', '0', 'sNormal', 'dSag')]
     else:
@@ -346,14 +346,16 @@ def twix2DCMOrientation(mapVBVDHdr, verbose=False):
 
     if ('sSpecPara', 'sVoI', 'sNormal', 'dCor') in mapVBVDHdr['MeasYaps']:
         NormaldCor = mapVBVDHdr['MeasYaps'][('sSpecPara', 'sVoI', 'sNormal', 'dCor')]
-    elif ('sSliceArray', 'asSlice', '0', 'sNormal', 'dCor') in mapVBVDHdr['MeasYaps']:
+    elif ('sSliceArray', 'asSlice', '0', 'sNormal', 'dCor') in mapVBVDHdr['MeasYaps']\
+            and not force_svs:
         NormaldCor = mapVBVDHdr['MeasYaps'][('sSliceArray', 'asSlice', '0', 'sNormal', 'dCor')]
     else:
         NormaldCor = 0.0
 
     if ('sSpecPara', 'sVoI', 'sNormal', 'dTra') in mapVBVDHdr['MeasYaps']:
         NormaldTra = mapVBVDHdr['MeasYaps'][('sSpecPara', 'sVoI', 'sNormal', 'dTra')]
-    elif ('sSliceArray', 'asSlice', '0', 'sNormal', 'dTra') in mapVBVDHdr['MeasYaps']:
+    elif ('sSliceArray', 'asSlice', '0', 'sNormal', 'dTra') in mapVBVDHdr['MeasYaps']\
+            and not force_svs:
         NormaldTra = mapVBVDHdr['MeasYaps'][('sSliceArray', 'asSlice', '0', 'sNormal', 'dTra')]
     else:
         NormaldTra = 0.0
@@ -365,7 +367,8 @@ def twix2DCMOrientation(mapVBVDHdr, verbose=False):
 
     TwixSliceNormal = np.array([NormaldSag, NormaldCor, NormaldTra], dtype=float)
 
-    if ('sSliceArray', 'asSlice', '0', 'dReadoutFOV') in mapVBVDHdr['MeasYaps']:
+    if ('sSliceArray', 'asSlice', '0', 'dReadoutFOV') in mapVBVDHdr['MeasYaps']\
+            and not force_svs:
         RoFoV = mapVBVDHdr['MeasYaps'][('sSliceArray', 'asSlice', '0', 'dReadoutFOV')]
         PeFoV = mapVBVDHdr['MeasYaps'][('sSliceArray', 'asSlice', '0', 'dPhaseFOV')]
     else:
@@ -377,10 +380,13 @@ def twix2DCMOrientation(mapVBVDHdr, verbose=False):
     imageOrientationPatient = np.stack((dRowVec_vector, dColVec_vector), axis=0)
 
     pixelSpacing = np.array([PeFoV, RoFoV])  # [RoFoV PeFoV];
-    if ('sSliceArray', 'asSlice', '0', 'dThickness') in mapVBVDHdr['MeasYaps']:
+    if ('sSliceArray', 'asSlice', '0', 'dThickness') in mapVBVDHdr['MeasYaps']\
+            and not force_svs:
         sliceThickness = mapVBVDHdr['MeasYaps'][('sSliceArray', 'asSlice', '0', 'dThickness')]
-    if ('sSpecPara', 'sVoI', 'dThickness') in mapVBVDHdr['MeasYaps']:
+    elif ('sSpecPara', 'sVoI', 'dThickness') in mapVBVDHdr['MeasYaps']:
         sliceThickness = mapVBVDHdr['MeasYaps'][('sSpecPara', 'sVoI', 'dThickness')]
+    else:
+        sliceThickness = 0.0
 
     # Position info (including table position)
     if ('sSpecPara', 'sVoI', 'sPosition', 'dSag') in mapVBVDHdr['MeasYaps']:
@@ -438,15 +444,15 @@ def examineTwix(twixObj, fileName, mraid):
         print(f'{ev: <15}:\t{tmpSqzDims: <20}\t{tmpSqzSize}')
 
 
-def extractTwixMetadata(mapVBVDHdr, orignal_file):
+def extractTwixMetadata(mapVBVDHdr, original_file):
     """Pass to appropriate extractTwixMetadata function for software version."""
     if xa_or_vx(mapVBVDHdr) == 'vx':
-        return extractTwixMetadata_vx(mapVBVDHdr, orignal_file)
+        return extractTwixMetadata_vx(mapVBVDHdr, original_file)
     elif xa_or_vx(mapVBVDHdr) == 'xa':
-        return extractTwixMetadata_xa(mapVBVDHdr, orignal_file)
+        return extractTwixMetadata_xa(mapVBVDHdr, original_file)
 
 
-def extractTwixMetadata_xa(mapVBVDHdr, orignal_file):
+def extractTwixMetadata_xa(mapVBVDHdr, original_file):
     """ Extract information from the pymapVBVD header to insert into the json sidecar.
 
     Args:
@@ -540,7 +546,7 @@ def extractTwixMetadata_xa(mapVBVDHdr, orignal_file):
     conversion_time = datetime.now().isoformat(sep='T', timespec='milliseconds')
     obj.set_standard_def('ConversionTime', conversion_time)
     # 'OriginalFile'
-    obj.set_standard_def('OriginalFile', [orignal_file, ])
+    obj.set_standard_def('OriginalFile', [original_file, ])
     # # 5.6 Spatial information
     # 'kSpace'
     obj.set_standard_def('kSpace', [False, False, False])
@@ -556,7 +562,7 @@ def extractTwixMetadata_xa(mapVBVDHdr, orignal_file):
     return obj
 
 
-def extractTwixMetadata_vx(mapVBVDHdr, orignal_file):
+def extractTwixMetadata_vx(mapVBVDHdr, original_file):
     """ Extract information from the pymapVBVD header to insert into the json sidecar.
 
     Function Twix files from Numaris4 Vx software scanners.
@@ -648,7 +654,7 @@ def extractTwixMetadata_vx(mapVBVDHdr, orignal_file):
     conversion_time = datetime.now().isoformat(sep='T', timespec='milliseconds')
     obj.set_standard_def('ConversionTime', conversion_time)
     # 'OriginalFile'
-    obj.set_standard_def('OriginalFile', [orignal_file, ])
+    obj.set_standard_def('OriginalFile', [original_file, ])
     # # 5.6 Spatial information
     # 'kSpace'
     obj.set_standard_def('kSpace', [False, False, False])
